@@ -1,36 +1,43 @@
-import json
-import math
 import os
 import platform
 import sys
 import time
 from enum import IntEnum, auto, unique
-from typing import List, Tuple
+from typing import List, Optional, Tuple
 
 import click
 import cv2
 import numpy as np
 from pydantic import ValidationError
+from PyQt5 import QtGui
+from PyQt5.QtCore import Qt, QThread, pyqtSignal, pyqtSlot
+from PyQt5.QtGui import QPixmap
+from PyQt5.QtWidgets import QApplication, QGridLayout, QLabel, QWidget
 from tqdm import tqdm
 
-from .commons import config_path_option
-from .config import Config, PresentationConfig, SlideConfig, SlideType
-from .defaults import CONFIG_PATH, FOLDER_PATH, FONT_ARGS
+from .commons import config_path_option, verbosity_option
+from .config import DEFAULT_CONFIG, Config, PresentationConfig, SlideConfig, SlideType
+from .defaults import FOLDER_PATH
+from .manim import logger
 
-INTERPOLATION_FLAGS = {
-    "nearest": cv2.INTER_NEAREST,
-    "linear": cv2.INTER_LINEAR,
-    "cubic": cv2.INTER_CUBIC,
-    "area": cv2.INTER_AREA,
-    "lanczos4": cv2.INTER_LANCZOS4,
-    "linear-exact": cv2.INTER_LINEAR_EXACT,
-    "nearest-exact": cv2.INTER_NEAREST_EXACT,
-}
+os.environ.pop(
+    "QT_QPA_PLATFORM_PLUGIN_PATH", None
+)  # See why here: https://stackoverflow.com/a/67863156
 
 WINDOW_NAME = "Manim Slides"
 WINDOW_INFO_NAME = f"{WINDOW_NAME}: Info"
 WINDOWS = platform.system() == "Windows"
 
+ASPECT_RATIO_MODES = {
+    "ignore": Qt.IgnoreAspectRatio,
+    "keep": Qt.KeepAspectRatio,
+}
+
+RESIZE_MODES = {
+    "fast": Qt.FastTransformation,
+    "smooth": Qt.SmoothTransformation,
+}
+
 
 @unique
 class State(IntEnum):
@@ -45,34 +52,29 @@ class State(IntEnum):
         return self.name.capitalize()
 
 
-def now() -> int:
-    """Returns time.time() in milliseconds."""
-    return round(time.time() * 1000)
-
-
-def fix_time(t: float) -> float:
-    """Clips time t such that it is always positive."""
-    return t if t > 0 else 1
+def now() -> float:
+    """Returns time.time() in seconds."""
+    return time.time()
 
 
 class Presentation:
     """Creates presentation from a configuration object."""
 
-    def __init__(self, config: PresentationConfig):
+    def __init__(self, config: PresentationConfig) -> None:
         self.slides: List[SlideConfig] = config.slides
         self.files: List[str] = config.files
 
-        self.current_slide_index = 0
-        self.current_animation = self.current_slide.start_animation
-        self.current_file = None
+        self.current_slide_index: int = 0
+        self.current_animation: int = self.current_slide.start_animation
+        self.current_file: Optional[str] = None
 
-        self.loaded_animation_cap = -1
+        self.loaded_animation_cap: int = -1
         self.cap = None  # cap = cv2.VideoCapture
 
-        self.reverse = False
-        self.reversed_animation = -1
+        self.reverse: bool = False
+        self.reversed_animation: int = -1
 
-        self.lastframe = None
+        self.lastframe: Optional[np.ndarray] = None
 
         self.reset()
         self.add_last_slide()
@@ -92,23 +94,25 @@ class Presentation:
         """Returns last slide."""
         return self.slides[-1]
 
-    def release_cap(self):
+    def release_cap(self) -> None:
         """Releases current Video Capture, if existing."""
-        if not self.cap is None:
+        if self.cap is not None:
             self.cap.release()
 
         self.loaded_animation_cap = -1
 
-    def load_animation_cap(self, animation: int):
+    def load_animation_cap(self, animation: int) -> None:
         """Loads video file of given animation."""
         # We must load a new VideoCapture file if:
         if (self.loaded_animation_cap != animation) or (
             self.reverse and self.reversed_animation != animation
         ):  # cap already loaded
 
+            logger.debug(f"Loading new cap for animation #{animation}")
+
             self.release_cap()
 
-            file = self.files[animation]
+            file: str = self.files[animation]
 
             if self.reverse:
                 file = "{}_reversed{}".format(*os.path.splitext(file))
@@ -125,29 +129,33 @@ class Presentation:
         self.load_animation_cap(self.current_animation)
         return self.cap
 
-    def rewind_current_slide(self):
+    def rewind_current_slide(self) -> None:
         """Rewinds current slide to first frame."""
+        logger.debug("Rewinding curring slide")
         if self.reverse:
             self.current_animation = self.current_slide.end_animation - 1
         else:
             self.current_animation = self.current_slide.start_animation
 
-        self.current_cap.set(cv2.CAP_PROP_POS_FRAMES, 0)
+        cap = self.current_cap
+        cap.set(cv2.CAP_PROP_POS_FRAMES, 0)
 
-    def cancel_reverse(self):
+    def cancel_reverse(self) -> None:
         """Cancels any effet produced by a reversed slide."""
         if self.reverse:
+            logger.debug("Cancelling effects from previous 'reverse' action'")
             self.reverse = False
             self.reversed_animation = -1
             self.release_cap()
 
-    def reverse_current_slide(self):
+    def reverse_current_slide(self) -> None:
         """Reverses current slide."""
         self.reverse = True
         self.rewind_current_slide()
 
-    def load_next_slide(self):
+    def load_next_slide(self) -> None:
         """Loads next slide."""
+        logger.debug("Loading next slide")
         if self.reverse:
             self.cancel_reverse()
             self.rewind_current_slide()
@@ -159,8 +167,9 @@ class Presentation:
             )
             self.rewind_current_slide()
 
-    def load_previous_slide(self):
+    def load_previous_slide(self) -> None:
         """Loads previous slide."""
+        logger.debug("Loading previous slide")
         self.cancel_reverse()
         self.current_slide_index = max(0, self.current_slide_index - 1)
         self.rewind_current_slide()
@@ -168,9 +177,14 @@ class Presentation:
     @property
     def fps(self) -> int:
         """Returns the number of frames per second of the current video."""
-        return self.current_cap.get(cv2.CAP_PROP_FPS)
+        fps = self.current_cap.get(cv2.CAP_PROP_FPS)
+        if fps == 0:
+            logger.warn(
+                f"Something is wrong with video file {self.current_file}, as the fps returned by frame {self.current_frame_number} is 0"
+            )
+        return max(fps, 1)  # TODO: understand why we sometimes get 0 fps
 
-    def add_last_slide(self):
+    def add_last_slide(self) -> None:
         """Add a 'last' slide to the end of slides."""
         self.slides.append(
             SlideConfig(
@@ -181,14 +195,14 @@ class Presentation:
             )
         )
 
-    def reset(self):
+    def reset(self) -> None:
         """Rests current presentation."""
         self.current_animation = 0
         self.load_animation_cap(0)
         self.current_slide_index = 0
         self.slides[-1].terminated = False
 
-    def load_last_slide(self):
+    def load_last_slide(self) -> None:
         """Loads last slide."""
         self.current_slide_index = len(self.slides) - 2
         assert (
@@ -265,65 +279,47 @@ class Presentation:
         return self.lastframe, state
 
 
-class Display:
+class Display(QThread):
     """Displays one or more presentations one after each other."""
 
+    change_video_signal = pyqtSignal(np.ndarray)
+    change_info_signal = pyqtSignal(dict)
+    finished = pyqtSignal()
+
     def __init__(
         self,
         presentations,
-        config,
+        config: Config = DEFAULT_CONFIG,
         start_paused=False,
-        fullscreen=False,
         skip_all=False,
-        resolution=(1980, 1080),
-        interpolation_flag=cv2.INTER_LINEAR,
         record_to=None,
-    ):
+        exit_after_last_slide=False,
+    ) -> None:
+        super().__init__()
         self.presentations = presentations
         self.start_paused = start_paused
         self.config = config
         self.skip_all = skip_all
-        self.fullscreen = fullscreen
-        self.resolution = resolution
-        self.interpolation_flag = interpolation_flag
         self.record_to = record_to
-        self.recordings = []
-        self.window_flags = (
-            cv2.WINDOW_GUI_NORMAL | cv2.WINDOW_FREERATIO | cv2.WINDOW_NORMAL
-        )
+        self.recordings: List[Tuple[str, int, int]] = []
 
         self.state = State.PLAYING
-        self.lastframe = None
+        self.lastframe: Optional[np.ndarray] = None
         self.current_presentation_index = 0
-        self.exit = False
+        self.run_flag = True
 
-        self.lag = 0
-        self.last_time = now()
-
-        cv2.namedWindow(
-            WINDOW_INFO_NAME,
-            cv2.WINDOW_GUI_NORMAL | cv2.WINDOW_FREERATIO | cv2.WINDOW_AUTOSIZE,
-        )
-
-        if self.fullscreen:
-            cv2.namedWindow(
-                WINDOW_NAME, cv2.WINDOW_GUI_NORMAL | cv2.WND_PROP_FULLSCREEN
-            )
-            cv2.setWindowProperty(
-                WINDOW_NAME, cv2.WND_PROP_FULLSCREEN, cv2.WINDOW_FULLSCREEN
-            )
-        else:
-            cv2.namedWindow(WINDOW_NAME, self.window_flags)
-            cv2.resizeWindow(WINDOW_NAME, *self.resolution)
+        self.key = -1
+        self.exit_after_last_slide = exit_after_last_slide
 
     @property
     def current_presentation(self) -> Presentation:
         """Returns the current presentation."""
         return self.presentations[self.current_presentation_index]
 
-    def run(self):
+    def run(self) -> None:
         """Runs a series of presentations until end or exit."""
-        while not self.exit:
+        while self.run_flag:
+            last_time = now()
             self.lastframe, self.state = self.current_presentation.update_state(
                 self.state
             )
@@ -333,88 +329,98 @@ class Display:
                     self.start_paused = False
             if self.state == State.END:
                 if self.current_presentation_index == len(self.presentations) - 1:
-                    self.quit()
-                    continue
+                    if self.exit_after_last_slide:
+                        self.run_flag = False
+                        continue
                 else:
                     self.current_presentation_index += 1
                     self.state = State.PLAYING
+
             self.handle_key()
-            if self.exit:
-                continue
             self.show_video()
             self.show_info()
 
-    def show_video(self):
-        """Shows updated video."""
-        self.lag = now() - self.last_time
-        self.last_time = now()
+            lag = now() - last_time
+            sleep_time = 1 / self.current_presentation.fps
+            sleep_time = max(sleep_time - lag, 0)
+            time.sleep(sleep_time)
+            last_time = now()
+        self.current_presentation.release_cap()
 
-        if not self.record_to is None:
+        if self.record_to is not None:
+            self.record_movie()
+
+        logger.debug("Closing video thread gracully and exiting")
+        self.finished.emit()
+
+    def record_movie(self) -> None:
+        logger.debug(
+            f"A total of {len(self.recordings)} frames will be saved to {self.record_to}"
+        )
+        file, frame_number, fps = self.recordings[0]
+
+        cap = cv2.VideoCapture(file)
+        cap.set(cv2.CAP_PROP_POS_FRAMES, frame_number - 1)
+        _, frame = cap.read()
+
+        w, h = frame.shape[:2]
+        fourcc = cv2.VideoWriter_fourcc(*"XVID")
+        out = cv2.VideoWriter(self.record_to, fourcc, fps, (h, w))
+
+        out.write(frame)
+
+        for _file, frame_number, _ in tqdm(
+            self.recordings[1:], desc="Creating recording file", leave=False
+        ):
+            if file != _file:
+                cap.release()
+                file = _file
+                cap = cv2.VideoCapture(_file)
+
+            cap.set(cv2.CAP_PROP_POS_FRAMES, frame_number - 1)
+            _, frame = cap.read()
+            out.write(frame)
+
+        cap.release()
+        out.release()
+
+    def show_video(self) -> None:
+        """Shows updated video."""
+        if self.record_to is not None:
             pres = self.current_presentation
             self.recordings.append(
                 (pres.current_file, pres.current_frame_number, pres.fps)
             )
 
-        frame = self.lastframe
+        frame: np.ndarray = self.lastframe
+        self.change_video_signal.emit(frame)
 
-        # If Window was manually closed (impossible in fullscreen),
-        # we reopen it
-        if cv2.getWindowProperty(WINDOW_NAME, cv2.WND_PROP_VISIBLE) < 1:
-            cv2.namedWindow(WINDOW_NAME, self.window_flags)
-            cv2.resizeWindow(WINDOW_NAME, *self.resolution)
-
-        if WINDOWS:  # Only resize on Windows
-            _, _, w, h = cv2.getWindowImageRect(WINDOW_NAME)
-
-            if (h, w) != frame.shape[:2]:  # Only if shape is different
-                frame = cv2.resize(frame, (w, h), self.interpolation_flag)
-
-        cv2.imshow(WINDOW_NAME, frame)
-
-    def show_info(self):
+    def show_info(self) -> None:
         """Shows updated information about presentations."""
-        info = np.zeros((130, 420), np.uint8)
-        font_args = (FONT_ARGS[0], 0.7, *FONT_ARGS[2:])
-        grid_x = [30, 230]
-        grid_y = [30, 70, 110]
-
-        cv2.putText(
-            info,
-            f"Animation: {self.current_presentation.current_animation}",
-            (grid_x[0], grid_y[0]),
-            *font_args,
-        )
-        cv2.putText(info, f"State: {self.state}", (grid_x[1], grid_y[0]), *font_args)
-
-        cv2.putText(
-            info,
-            f"Slide {self.current_presentation.current_slide.number}/{len(self.current_presentation.slides)}",
-            (grid_x[0], grid_y[1]),
-            *font_args,
-        )
-        cv2.putText(
-            info,
-            f"Slide Type: {self.current_presentation.current_slide.type}",
-            (grid_x[1], grid_y[1]),
-            *font_args,
+        self.change_info_signal.emit(
+            {
+                "animation": self.current_presentation.current_animation,
+                "state": self.state,
+                "slide_index": self.current_presentation.current_slide.number,
+                "n_slides": len(self.current_presentation.slides),
+                "type": self.current_presentation.current_slide.type,
+                "scene_index": self.current_presentation_index + 1,
+                "n_scenes": len(self.presentations),
+            }
         )
 
-        cv2.putText(
-            info,
-            f"Scene  {self.current_presentation_index + 1}/{len(self.presentations)}",
-            ((grid_x[0] + grid_x[1]) // 2, grid_y[2]),
-            *font_args,
-        )
+    @pyqtSlot(int)
+    def set_key(self, key: int) -> None:
+        """Sets the next key to be handled."""
+        self.key = key
 
-        cv2.imshow(WINDOW_INFO_NAME, info)
-
-    def handle_key(self):
+    def handle_key(self) -> None:
         """Handles key strokes."""
-        sleep_time = math.ceil(1000 / self.current_presentation.fps)
-        key = cv2.waitKeyEx(fix_time(sleep_time - self.lag))
+
+        key = self.key
 
         if self.config.QUIT.match(key):
-            self.quit()
+            self.run_flag = False
         elif self.state == State.PLAYING and self.config.PLAY_PAUSE.match(key):
             self.state = State.PAUSED
         elif self.state == State.PAUSED and self.config.PLAY_PAUSE.match(key):
@@ -447,39 +453,180 @@ class Display:
             self.current_presentation.rewind_current_slide()
             self.state = State.PLAYING
 
-    def quit(self):
-        """Destroys all windows created by presentations and exits gracefully."""
-        cv2.destroyAllWindows()
+        self.key = -1  # No more key to be handled
 
-        if not self.record_to is None and len(self.recordings) > 0:
-            file, frame_number, fps = self.recordings[0]
+    def stop(self):
+        """Stops current thread, without doing anything after."""
+        self.run_flag = False
+        self.wait()
 
-            cap = cv2.VideoCapture(file)
-            cap.set(cv2.CAP_PROP_POS_FRAMES, frame_number - 1)
-            _, frame = cap.read()
 
-            w, h = frame.shape[:2]
-            fourcc = cv2.VideoWriter_fourcc(*"XVID")
-            out = cv2.VideoWriter(self.record_to, fourcc, fps, (h, w))
+class Info(QWidget):
+    def __init__(self):
+        super().__init__()
+        self.setWindowTitle(WINDOW_INFO_NAME)
 
-            out.write(frame)
+        self.layout = QGridLayout()
 
-            for _file, frame_number, _ in tqdm(
-                self.recordings[1:], desc="Creating recording file", leave=False
-            ):
-                if file != _file:
-                    cap.release()
-                    file = _file
-                    cap = cv2.VideoCapture(_file)
+        self.setLayout(self.layout)
 
-                cap.set(cv2.CAP_PROP_POS_FRAMES, frame_number - 1)
-                _, frame = cap.read()
-                out.write(frame)
+        self.animationLabel = QLabel()
+        self.stateLabel = QLabel()
+        self.slideLabel = QLabel()
+        self.typeLabel = QLabel()
+        self.sceneLabel = QLabel()
 
-            cap.release()
-            out.release()
+        self.layout.addWidget(self.animationLabel, 0, 0, 1, 2)
+        self.layout.addWidget(self.stateLabel, 1, 0)
+        self.layout.addWidget(self.slideLabel, 1, 1)
+        self.layout.addWidget(self.typeLabel, 2, 0)
+        self.layout.addWidget(self.sceneLabel, 2, 1)
 
-        self.exit = True
+        self.update_info({})
+
+    @pyqtSlot(dict)
+    def update_info(self, info: dict):
+        self.animationLabel.setText("Animation: {}".format(info.get("animation", "na")))
+        self.stateLabel.setText("State: {}".format(info.get("state", "unknown")))
+        self.slideLabel.setText(
+            "Slide: {}/{}".format(
+                info.get("slide_index", "na"), info.get("n_slides", "na")
+            )
+        )
+        self.typeLabel.setText("Slide Type: {}".format(info.get("type", "unknown")))
+        self.sceneLabel.setText(
+            "Scene: {}/{}".format(
+                info.get("scene_index", "na"), info.get("n_scenes", "na")
+            )
+        )
+
+
+class InfoThread(QThread):
+    def __init__(self):
+        super().__init__()
+        self.dialog = Info()
+        self.run_flag = True
+
+    def start(self):
+        super().start()
+
+        self.dialog.show()
+
+    def stop(self):
+        self.dialog.deleteLater()
+
+
+class App(QWidget):
+    send_key_signal = pyqtSignal(int)
+
+    def __init__(
+        self,
+        *args,
+        config: Config = DEFAULT_CONFIG,
+        fullscreen: bool = False,
+        resolution: Tuple[int, int] = (1980, 1080),
+        hide_mouse: bool = False,
+        aspect_ratio: Qt.AspectRatioMode = Qt.IgnoreAspectRatio,
+        resize_mode: Qt.TransformationMode = Qt.SmoothTransformation,
+        **kwargs,
+    ):
+        super().__init__()
+
+        self.setWindowTitle(WINDOW_NAME)
+        self.display_width, self.display_height = resolution
+        self.aspect_ratio = aspect_ratio
+        self.resize_mode = resize_mode
+        self.hide_mouse = hide_mouse
+        self.config = config
+        if self.hide_mouse:
+            self.setCursor(Qt.BlankCursor)
+
+        self.label = QLabel(self)
+        self.label.setAlignment(Qt.AlignCenter)
+        self.label.resize(self.display_width, self.display_height)
+
+        self.pixmap = QPixmap(self.width(), self.height())
+        self.label.setPixmap(self.pixmap)
+        self.label.setMinimumSize(1, 1)
+
+        # create the video capture thread
+        self.thread = Display(*args, config=config, **kwargs)
+        # create the info dialog
+        self.info = Info()
+        self.info.show()
+
+        # info widget will also listen to key presses
+        self.info.keyPressEvent = self.keyPressEvent
+
+        if fullscreen:
+            self.showFullScreen()
+
+        # connect signals
+        self.thread.change_video_signal.connect(self.update_image)
+        self.thread.change_info_signal.connect(self.info.update_info)
+        self.thread.finished.connect(self.closeAll)
+        self.send_key_signal.connect(self.thread.set_key)
+
+        # start the thread
+        self.thread.start()
+
+    def keyPressEvent(self, event):
+
+        key = event.key()
+        if self.config.HIDE_MOUSE.match(key):
+            if self.hide_mouse:
+                self.setCursor(Qt.ArrowCursor)
+                self.hide_mouse = False
+            else:
+                self.setCursor(Qt.BlankCursor)
+                self.hide_mouse = True
+        # We send key to be handled by video display
+        self.send_key_signal.emit(key)
+        event.accept()
+
+    def closeAll(self):
+        logger.debug("Closing all QT windows")
+        self.thread.stop()
+        self.info.deleteLater()
+        self.deleteLater()
+
+    def resizeEvent(self, event):
+        self.pixmap = self.pixmap.scaled(
+            self.width(), self.height(), self.aspect_ratio, self.resize_mode
+        )
+        self.label.setPixmap(self.pixmap)
+        self.label.resize(self.width(), self.height())
+
+    def closeEvent(self, event):
+        self.closeAll()
+        event.accept()
+
+    @pyqtSlot(np.ndarray)
+    def update_image(self, cv_img: dict):
+        """Updates the image_label with a new opencv image"""
+        self.pixmap = self.convert_cv_qt(cv_img)
+        self.label.setPixmap(self.pixmap)
+
+    @pyqtSlot(dict)
+    def update_info(self, info: dict):
+        """Updates the image_label with a new opencv image"""
+        pass
+
+    def convert_cv_qt(self, cv_img):
+        """Convert from an opencv image to QPixmap"""
+        rgb_image = cv2.cvtColor(cv_img, cv2.COLOR_BGR2RGB)
+        h, w, ch = rgb_image.shape
+        bytes_per_line = ch * w
+        convert_to_Qt_format = QtGui.QImage(
+            rgb_image.data, w, h, bytes_per_line, QtGui.QImage.Format_RGB888
+        )
+        p = convert_to_Qt_format.scaled(
+            self.width(),
+            self.height(),
+            self.aspect_ratio,
+            self.resize_mode,
+        )
+        return QPixmap.fromImage(p)
 
 
 @click.command()
@@ -491,7 +638,8 @@ class Display:
     show_default=True,
 )
 @click.help_option("-h", "--help")
-def list_scenes(folder):
+@verbosity_option
+def list_scenes(folder) -> None:
     """List available scenes."""
 
     for i, scene in enumerate(_list_scenes(folder), start=1):
@@ -504,13 +652,18 @@ def _list_scenes(folder) -> List[str]:
 
     for file in os.listdir(folder):
         if file.endswith(".json"):
+            filepath = os.path.join(folder, file)
             try:
-                filepath = os.path.join(folder, file)
                 _ = PresentationConfig.parse_file(filepath)
                 scenes.append(os.path.basename(file)[:-5])
-            except Exception:  # Could not parse this file as a proper presentation config
+            except Exception as e:  # Could not parse this file as a proper presentation config
+                logger.warn(
+                    f"Something went wrong with parsing presentation config `{filepath}`: {e}"
+                )
                 pass
 
+    logger.debug(f"Found {len(scenes)} valid scene configuration files in `{folder}`.")
+
     return scenes
 
 
@@ -527,9 +680,10 @@ def _list_scenes(folder) -> List[str]:
 @click.option("--start-paused", is_flag=True, help="Start paused.")
 @click.option("--fullscreen", is_flag=True, help="Fullscreen mode.")
 @click.option(
+    "-s",
     "--skip-all",
     is_flag=True,
-    help="Skip all slides, useful the test if slides are working.",
+    help="Skip all slides, useful the test if slides are working. Automatically sets `--skip-after-last-slide` to True.",
 )
 @click.option(
     "-r",
@@ -540,20 +694,39 @@ def _list_scenes(folder) -> List[str]:
     show_default=True,
 )
 @click.option(
-    "-i",
-    "--interpolation-flag",
-    type=click.Choice(INTERPOLATION_FLAGS.keys(), case_sensitive=False),
-    default="linear",
-    help="Set the interpolation flag to be used when resizing image. See OpenCV cv::InterpolationFlags.",
-    show_default=True,
-)
-@click.option(
+    "--to",
     "--record-to",
+    "record_to",
     type=click.Path(dir_okay=False),
     default=None,
     help="If set, the presentation will be recorded into a AVI video file with given name.",
 )
+@click.option(
+    "--exit-after-last-slide",
+    is_flag=True,
+    help="At the end of last slide, the application will be exited.",
+)
+@click.option(
+    "--hide-mouse",
+    is_flag=True,
+    help="Hide mouse cursor.",
+)
+@click.option(
+    "--aspect-ratio",
+    type=click.Choice(ASPECT_RATIO_MODES.keys(), case_sensitive=False),
+    default="ignore",
+    help="Set the aspect ratio mode to be used when rescaling video.",
+    show_default=True,
+)
+@click.option(
+    "--resize-mode",
+    type=click.Choice(RESIZE_MODES.keys(), case_sensitive=False),
+    default="smooth",
+    help="Set the resize (i.e., transformation) mode to be used when rescaling video.",
+    show_default=True,
+)
 @click.help_option("-h", "--help")
+@verbosity_option
 def present(
     scenes,
     config_path,
@@ -562,9 +735,12 @@ def present(
     fullscreen,
     skip_all,
     resolution,
-    interpolation_flag,
     record_to,
-):
+    exit_after_last_slide,
+    hide_mouse,
+    aspect_ratio,
+    resize_mode,
+) -> None:
     """
     Present SCENE(s), one at a time, in order.
 
@@ -575,6 +751,9 @@ def present(
     Use `manim-slide list-scenes` to list all available scenes in a given folder.
     """
 
+    if skip_all:
+        exit_after_last_slide = True
+
     if len(scenes) == 0:
         scene_choices = _list_scenes(folder)
 
@@ -588,10 +767,10 @@ def present(
         click.echo("Choose number corresponding to desired scene/arguments.")
         click.echo("(Use comma separated list for multiple entries)")
 
-        def value_proc(value: str):
+        def value_proc(value: str) -> List[str]:
             indices = list(map(int, value.strip().replace(" ", "").split(",")))
 
-            if not all(map(lambda i: 0 < i <= len(scene_choices), indices)):
+            if not all(0 < i <= len(scene_choices) for i in indices):
                 raise click.UsageError(
                     "Please only enter numbers displayed on the screen."
                 )
@@ -610,7 +789,7 @@ def present(
             except ValueError as e:
                 raise click.UsageError(e)
 
-    presentations = list()
+    presentations = []
     for scene in scenes:
         config_file = os.path.join(folder, f"{scene}.json")
         if not os.path.exists(config_file):
@@ -618,8 +797,8 @@ def present(
                 f"File {config_file} does not exist, check the scene name and make sure to use Slide as your scene base class"
             )
         try:
-            config = PresentationConfig.parse_file(config_file)
-            presentations.append(Presentation(config))
+            pres_config = PresentationConfig.parse_file(config_file)
+            presentations.append(Presentation(pres_config))
         except ValidationError as e:
             raise click.UsageError(str(e))
 
@@ -629,23 +808,31 @@ def present(
         except ValidationError as e:
             raise click.UsageError(str(e))
     else:
+        logger.debug("No configuration file found, using default configuration.")
         config = Config()
 
-    if not record_to is None:
+    if record_to is not None:
         _, ext = os.path.splitext(record_to)
         if ext.lower() != ".avi":
             raise click.UsageError(
-                f"Recording only support '.avi' extension. For other video formats, please convert the resulting '.avi' file afterwards."
+                "Recording only support '.avi' extension. For other video formats, please convert the resulting '.avi' file afterwards."
             )
 
-    display = Display(
+    app = QApplication(sys.argv)
+    app.setApplicationName("Manim Slides")
+    a = App(
         presentations,
         config=config,
         start_paused=start_paused,
         fullscreen=fullscreen,
         skip_all=skip_all,
         resolution=resolution,
-        interpolation_flag=INTERPOLATION_FLAGS[interpolation_flag],
         record_to=record_to,
+        exit_after_last_slide=exit_after_last_slide,
+        hide_mouse=hide_mouse,
+        aspect_ratio=ASPECT_RATIO_MODES[aspect_ratio],
+        resize_mode=RESIZE_MODES[resize_mode],
     )
-    display.run()
+    a.show()
+    sys.exit(app.exec_())
+    logger.debug("After")
